==> foundation-2.0.4.tgz: package/lib/esm/Link.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import useTheme from "./useTheme";
import { useContext } from "react";
import navigationContext from "./navigationContext";
import { useIsInline } from "./text";
export default (function (_a) {
    var _b;
    var children = _a.children, props = __rest(_a, ["children"]);
    var _c = useTheme(), c = _c.c, s = _c.s;
    var navigationFn = useContext(navigationContext);
    var isInline = useIsInline();
    var inline = (_b = props.inline) !== null && _b !== void 0 ? _b : isInline;
    return (_jsx("a", __assign({ href: props.to, target: props.newWindow ? "_blank" : undefined, css: css({
            display: inline ? "inline-block" : "block",
            borderRadius: s.xxs,
            "&:focus-visible": {
                outline: "".concat(s.xxs, " solid ").concat(c.outline),
            },
        }), onClick: function (e) {
            if (!props.useNativeNavigation && navigationFn) {
                e.preventDefault();
                navigationFn(props.to);
            }
        } }, { children: children })));
});

==> foundation-2.2.0.tgz: package/lib/esm/Link.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
import { css } from "@emotion/react";
import { useContext } from "react";
import navigationContext from "./navigationContext";
import { useIsInline } from "./text";
import useOutlineCss from "./useOutlineCss";
export default (function (_a) {
    var _b;
    var children = _a.children, props = __rest(_a, ["children"]);
    var navigationFn = useContext(navigationContext);
    var isInline = useIsInline();
    var inline = (_b = props.inline) !== null && _b !== void 0 ? _b : isInline;
    var outline = useOutlineCss();
    return (_jsx("a", __assign({ href: props.to, target: props.newWindow ? "_blank" : undefined, css: css({
            display: inline ? "inline-block" : "block",
        }, outline), onClick: function (e) {
            if (!props.useNativeNavigation && navigationFn) {
                e.preventDefault();
                navigationFn(props.to);
            }
        } }, { children: children })));
});
